============
unreferenced
============

Reports unreferenced files (as candidates for removal).


Installation
============

To install *unreferenced*::

    $ pip install unreferenced


Usage
=====

::

    $ unreferenced .
    ./junk.py
    ./unused.png


Links
=====

.. image:: https://travis-ci.org/myint/unreferenced.png?branch=master
    :target: https://travis-ci.org/myint/unreferenced
    :alt: Build status
